==> bus-vortex-8.3.1-sources.jar: org/miaixz/bus/vortex/Registry.java <==
/*
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 ~                                                                               ~
 ~ The MIT License (MIT)                                                         ~
 ~                                                                               ~
 ~ Copyright (c) 2015-2025 miaixz.org and other contributors.                    ~
 ~                                                                               ~
 ~ Permission is hereby granted, free of charge, to any person obtaining a copy  ~
 ~ of this software and associated documentation files (the "Software"), to deal ~
 ~ in the Software without restriction, including without limitation the rights  ~
 ~ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     ~
 ~ copies of the Software, and to permit persons to whom the Software is         ~
 ~ furnished to do so, subject to the following conditions:                      ~
 ~                                                                               ~
 ~ The above copyright notice and this permission notice shall be included in    ~
 ~ all copies or substantial portions of the Software.                           ~
 ~                                                                               ~
 ~ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    ~
 ~ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      ~
 ~ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   ~
 ~ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        ~
 ~ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, ~
 ~ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     ~
 ~ THE SOFTWARE.                                                                 ~
 ~                                                                               ~
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
*/
package org.miaixz.bus.vortex;

/**
 * 通用注册表接口，用于管理和操作键值对数据（如路由、限流配置等）
 *
 * @param <T> 注册表中存储的值类型
 * @author Justubborn
 * @since Java 17+
 */
public interface Registry<T> {

    /**
     * 初始化注册表，加载初始数据或配置
     */
    void init();

    /**
     * 添加键值对到注册表
     *
     * @param key 键，唯一标识
     * @param reg 值，待注册的对象
     * @return 如果添加成功返回 true，否则返回 false
     */
    boolean add(String key, T reg);

    /**
     * 从注册表中移除指定键的记录
     *
     * @param key 键，唯一标识
     * @return 如果移除成功返回 true，否则返回 false
     */
    boolean remove(String key);

    /**
     * 修改注册表中的键值对
     *
     * @param key 键，唯一标识
     * @param reg 新的值
     * @return 如果修改成功返回 true，否则返回 false
     */
    boolean amend(String key, T reg);

    /**
     * 刷新注册表，重新加载数据或清空后初始化
     */
    void refresh();

    /**
     * 获取指定键对应的值
     *
     * @param id 键，唯一标识
     * @return 对应的值，若不存在返回 null
     */
    T get(String id);

}

==> bus-vortex-8.3.2-sources.jar: org/miaixz/bus/vortex/Registry.java <==
/*
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 ~                                                                               ~
 ~ The MIT License (MIT)                                                         ~
 ~                                                                               ~
 ~ Copyright (c) 2015-2025 miaixz.org and other contributors.                    ~
 ~                                                                               ~
 ~ Permission is hereby granted, free of charge, to any person obtaining a copy  ~
 ~ of this software and associated documentation files (the "Software"), to deal ~
 ~ in the Software without restriction, including without limitation the rights  ~
 ~ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     ~
 ~ copies of the Software, and to permit persons to whom the Software is         ~
 ~ furnished to do so, subject to the following conditions:                      ~
 ~                                                                               ~
 ~ The above copyright notice and this permission notice shall be included in    ~
 ~ all copies or substantial portions of the Software.                           ~
 ~                                                                               ~
 ~ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    ~
 ~ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      ~
 ~ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   ~
 ~ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        ~
 ~ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, ~
 ~ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     ~
 ~ THE SOFTWARE.                                                                 ~
 ~                                                                               ~
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
*/
package org.miaixz.bus.vortex;

/**
 * Generic registry interface for managing and operating key-value pair data (e.g., routes, rate limiting
 * configurations).
 *
 * @param <T> The type of value stored in the registry.
 * @author Justubborn
 * @since Java 17+
 */
public interface Registry<T> {

    /**
     * Initializes the registry, loading initial data or configurations.
     */
    void init();

    /**
     * Adds a key-value pair to the registry.
     *
     * @param key The unique identifier key.
     * @param reg The object to be registered.
     * @return {@code true} if the addition was successful, {@code false} otherwise.
     */
    boolean add(String key, T reg);

    /**
     * Removes a record with the specified key from the registry.
     *
     * @param key The unique identifier key.
     * @return {@code true} if the removal was successful, {@code false} otherwise.
     */
    boolean remove(String key);

    /**
     * Modifies a key-value pair in the registry.
     *
     * @param key The unique identifier key.
     * @param reg The new value.
     * @return {@code true} if the modification was successful, {@code false} otherwise.
     */
    boolean amend(String key, T reg);

    /**
     * Refreshes the registry, reloading data or clearing and reinitializing.
     */
    void refresh();

    /**
     * Retrieves the value corresponding to the specified key.
     *
     * @param id The unique identifier key.
     * @return The corresponding value, or {@code null} if not found.
     */
    T get(String id);

}
